Class: Google::Apis::BatchV1::Environment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/batch_v1/classes.rb,
lib/google/apis/batch_v1/representations.rb,
lib/google/apis/batch_v1/representations.rb

Overview

An Environment describes a collection of environment variables to set when executing Tasks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Environment

Returns a new instance of Environment.



1113
1114
1115
# File 'lib/google/apis/batch_v1/classes.rb', line 1113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encrypted_variablesGoogle::Apis::BatchV1::KmsEnvMap

An encrypted JSON dictionary where the key/value pairs correspond to environment variable names and their values. Corresponds to the JSON property encryptedVariables



1100
1101
1102
# File 'lib/google/apis/batch_v1/classes.rb', line 1100

def encrypted_variables
  @encrypted_variables
end

#secret_variablesHash<String,String>

A map of environment variable names to Secret Manager secret names. The VM will access the named secrets to set the value of each environment variable. Corresponds to the JSON property secretVariables

Returns:

  • (Hash<String,String>)


1106
1107
1108
# File 'lib/google/apis/batch_v1/classes.rb', line 1106

def secret_variables
  @secret_variables
end

#variablesHash<String,String>

A map of environment variable names to values. Corresponds to the JSON property variables

Returns:

  • (Hash<String,String>)


1111
1112
1113
# File 'lib/google/apis/batch_v1/classes.rb', line 1111

def variables
  @variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1118
1119
1120
1121
1122
# File 'lib/google/apis/batch_v1/classes.rb', line 1118

def update!(**args)
  @encrypted_variables = args[:encrypted_variables] if args.key?(:encrypted_variables)
  @secret_variables = args[:secret_variables] if args.key?(:secret_variables)
  @variables = args[:variables] if args.key?(:variables)
end