Class: Google::Apis::BatchV1::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/batch_v1/classes.rb,
lib/google/apis/batch_v1/representations.rb,
lib/google/apis/batch_v1/representations.rb

Overview

The Cloud Batch Job description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



1394
1395
1396
# File 'lib/google/apis/batch_v1/classes.rb', line 1394

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocation_policyGoogle::Apis::BatchV1::AllocationPolicy

A Job's resource allocation policy describes when, where, and how compute resources should be allocated for the Job. Corresponds to the JSON property allocationPolicy



1328
1329
1330
# File 'lib/google/apis/batch_v1/classes.rb', line 1328

def allocation_policy
  @allocation_policy
end

#create_timeString

Output only. When the Job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1333
1334
1335
# File 'lib/google/apis/batch_v1/classes.rb', line 1333

def create_time
  @create_time
end

#labelsHash<String,String>

Custom labels to apply to the job and any Cloud Logging LogEntry that it generates. Use labels to group and describe the resources they are applied to. Batch automatically applies predefined labels and supports multiple labels fields for each job, which each let you apply custom labels to various resources. Label names that start with "goog-" or "google-" are reserved for predefined labels. For more information about labels with Batch, see Organize resources using labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1346
1347
1348
# File 'lib/google/apis/batch_v1/classes.rb', line 1346

def labels
  @labels
end

#logs_policyGoogle::Apis::BatchV1::LogsPolicy

LogsPolicy describes if and how a job's logs are preserved. Logs include information that is automatically written by the Batch service agent and any information that you configured the job's runnables to write to the stdout or stderr streams. Corresponds to the JSON property logsPolicy



1354
1355
1356
# File 'lib/google/apis/batch_v1/classes.rb', line 1354

def logs_policy
  @logs_policy
end

#nameString

Output only. Job name. For example: "projects/123456/locations/us-central1/ jobs/job01". Corresponds to the JSON property name

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/batch_v1/classes.rb', line 1360

def name
  @name
end

#notificationsArray<Google::Apis::BatchV1::JobNotification>

Notification configurations. Corresponds to the JSON property notifications



1365
1366
1367
# File 'lib/google/apis/batch_v1/classes.rb', line 1365

def notifications
  @notifications
end

#priorityFixnum

Priority of the Job. The valid value range is [0, 100). Default value is 0. Higher value indicates higher priority. A job with higher priority value is more likely to run earlier if all other requirements are satisfied. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1372
1373
1374
# File 'lib/google/apis/batch_v1/classes.rb', line 1372

def priority
  @priority
end

#statusGoogle::Apis::BatchV1::JobStatus

Job status. Corresponds to the JSON property status



1377
1378
1379
# File 'lib/google/apis/batch_v1/classes.rb', line 1377

def status
  @status
end

#task_groupsArray<Google::Apis::BatchV1::TaskGroup>

Required. TaskGroups in the Job. Only one TaskGroup is supported now. Corresponds to the JSON property taskGroups



1382
1383
1384
# File 'lib/google/apis/batch_v1/classes.rb', line 1382

def task_groups
  @task_groups
end

#uidString

Output only. A system generated unique ID for the Job. Corresponds to the JSON property uid

Returns:

  • (String)


1387
1388
1389
# File 'lib/google/apis/batch_v1/classes.rb', line 1387

def uid
  @uid
end

#update_timeString

Output only. The last time the Job was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1392
1393
1394
# File 'lib/google/apis/batch_v1/classes.rb', line 1392

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
# File 'lib/google/apis/batch_v1/classes.rb', line 1399

def update!(**args)
  @allocation_policy = args[:allocation_policy] if args.key?(:allocation_policy)
  @create_time = args[:create_time] if args.key?(:create_time)
  @labels = args[:labels] if args.key?(:labels)
  @logs_policy = args[:logs_policy] if args.key?(:logs_policy)
  @name = args[:name] if args.key?(:name)
  @notifications = args[:notifications] if args.key?(:notifications)
  @priority = args[:priority] if args.key?(:priority)
  @status = args[:status] if args.key?(:status)
  @task_groups = args[:task_groups] if args.key?(:task_groups)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end