Class: Google::Apis::BatchV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/batch_v1/classes.rb,
lib/google/apis/batch_v1/representations.rb,
lib/google/apis/batch_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



2019
2020
2021
# File 'lib/google/apis/batch_v1/classes.rb', line 2019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1983
1984
1985
# File 'lib/google/apis/batch_v1/classes.rb', line 1983

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1988
1989
1990
# File 'lib/google/apis/batch_v1/classes.rb', line 1988

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1993
1994
1995
# File 'lib/google/apis/batch_v1/classes.rb', line 1993

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2001
2002
2003
# File 'lib/google/apis/batch_v1/classes.rb', line 2001

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2007
2008
2009
# File 'lib/google/apis/batch_v1/classes.rb', line 2007

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/batch_v1/classes.rb', line 2012

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2017
2018
2019
# File 'lib/google/apis/batch_v1/classes.rb', line 2017

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2024
2025
2026
2027
2028
2029
2030
2031
2032
# File 'lib/google/apis/batch_v1/classes.rb', line 2024

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end