Class: Google::Apis::BatchV1::TaskExecution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/batch_v1/classes.rb,
lib/google/apis/batch_v1/representations.rb,
lib/google/apis/batch_v1/representations.rb

Overview

This Task Execution field includes detail information for task execution procedures, based on StatusEvent types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskExecution

Returns a new instance of TaskExecution.



2409
2410
2411
# File 'lib/google/apis/batch_v1/classes.rb', line 2409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exit_codeFixnum

The exit code of a finished task. If the task succeeded, the exit code will be

  1. If the task failed but not due to the following reasons, the exit code will be 50000. Otherwise, it can be from different sources: * Batch known failures: https://cloud.google.com/batch/docs/troubleshooting#reserved-exit-codes. * Batch runnable execution failures; you can rely on Batch logs to further diagnose: https://cloud.google.com/batch/docs/analyze-job-using-logs. If there are multiple runnables failures, Batch only exposes the first error. Corresponds to the JSON property exitCode

Returns:

  • (Fixnum)


2407
2408
2409
# File 'lib/google/apis/batch_v1/classes.rb', line 2407

def exit_code
  @exit_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2414
2415
2416
# File 'lib/google/apis/batch_v1/classes.rb', line 2414

def update!(**args)
  @exit_code = args[:exit_code] if args.key?(:exit_code)
end