Class: Google::Apis::BatchV1::BatchService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BatchV1::BatchService
- Defined in:
- lib/google/apis/batch_v1/service.rb
Overview
Batch API
An API to manage the running of Batch resources on Google Cloud Platform.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://batch.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_job(name, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Operation
Cancel a Job.
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_job(parent, job_object = nil, job_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Job
Create a Job.
-
#delete_project_location_job(name, reason: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Operation
Delete a Job.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Location
Gets information about a location.
-
#get_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Job
Get a Job specified by its resource name.
-
#get_project_location_job_task_group_task(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Task
Return a single Task.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ BatchService
constructor
A new instance of BatchService.
-
#list_project_location_job_task_group_tasks(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListTasksResponse
List Tasks associated with a job.
-
#list_project_location_jobs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListJobsResponse
List all Jobs for a project within a region.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#report_agent_state(parent, report_agent_state_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ReportAgentStateResponse
Report agent's state, e.g.
Constructor Details
#initialize ⇒ BatchService
Returns a new instance of BatchService.
47 48 49 50 51 52 |
# File 'lib/google/apis/batch_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-batch_v1', client_version: Google::Apis::BatchV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/batch_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/batch_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_job(name, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Operation
Cancel a Job.
161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/google/apis/batch_v1/service.rb', line 161 def cancel_job(name, cancel_job_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::BatchV1::CancelJobRequest::Representation command.request_object = cancel_job_request_object command.response_representation = Google::Apis::BatchV1::Operation::Representation command.response_class = Google::Apis::BatchV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/google/apis/batch_v1/service.rb', line 444 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::BatchV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::BatchV1::Empty::Representation command.response_class = Google::Apis::BatchV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_job(parent, job_object = nil, job_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Job
Create a Job.
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/google/apis/batch_v1/service.rb', line 213 def create_project_location_job(parent, job_object = nil, job_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/jobs', ) command.request_representation = Google::Apis::BatchV1::Job::Representation command.request_object = job_object command.response_representation = Google::Apis::BatchV1::Job::Representation command.response_class = Google::Apis::BatchV1::Job command.params['parent'] = parent unless parent.nil? command.query['jobId'] = job_id unless job_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_job(name, reason: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Operation
Delete a Job.
260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/google/apis/batch_v1/service.rb', line 260 def delete_project_location_job(name, reason: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BatchV1::Operation::Representation command.response_class = Google::Apis::BatchV1::Operation command.params['name'] = name unless name.nil? command.query['reason'] = reason unless reason.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
479 480 481 482 483 484 485 486 487 |
# File 'lib/google/apis/batch_v1/service.rb', line 479 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BatchV1::Empty::Representation command.response_class = Google::Apis::BatchV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/batch_v1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BatchV1::Location::Representation command.response_class = Google::Apis::BatchV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Job
Get a Job specified by its resource name.
292 293 294 295 296 297 298 299 300 |
# File 'lib/google/apis/batch_v1/service.rb', line 292 def get_project_location_job(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BatchV1::Job::Representation command.response_class = Google::Apis::BatchV1::Job command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_job_task_group_task(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Task
Return a single Task.
365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/batch_v1/service.rb', line 365 def get_project_location_job_task_group_task(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BatchV1::Task::Representation command.response_class = Google::Apis::BatchV1::Task command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
510 511 512 513 514 515 516 517 518 |
# File 'lib/google/apis/batch_v1/service.rb', line 510 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BatchV1::Operation::Representation command.response_class = Google::Apis::BatchV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_job_task_group_tasks(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListTasksResponse
List Tasks associated with a job.
403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/google/apis/batch_v1/service.rb', line 403 def list_project_location_job_task_group_tasks(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/tasks', ) command.response_representation = Google::Apis::BatchV1::ListTasksResponse::Representation command.response_class = Google::Apis::BatchV1::ListTasksResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_jobs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListJobsResponse
List all Jobs for a project within a region.
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/google/apis/batch_v1/service.rb', line 331 def list_project_location_jobs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/jobs', ) command.response_representation = Google::Apis::BatchV1::ListJobsResponse::Representation command.response_class = Google::Apis::BatchV1::ListJobsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/google/apis/batch_v1/service.rb', line 555 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::BatchV1::ListOperationsResponse::Representation command.response_class = Google::Apis::BatchV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/batch_v1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::BatchV1::ListLocationsResponse::Representation command.response_class = Google::Apis::BatchV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#report_agent_state(parent, report_agent_state_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BatchV1::ReportAgentStateResponse
Report agent's state, e.g. agent status and tasks information
591 592 593 594 595 596 597 598 599 600 601 |
# File 'lib/google/apis/batch_v1/service.rb', line 591 def report_agent_state(parent, report_agent_state_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/state:report', ) command.request_representation = Google::Apis::BatchV1::ReportAgentStateRequest::Representation command.request_object = report_agent_state_request_object command.response_representation = Google::Apis::BatchV1::ReportAgentStateResponse::Representation command.response_class = Google::Apis::BatchV1::ReportAgentStateResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |