Class: Google::Apis::BatchV1::Message
- Inherits:
-
Object
- Object
- Google::Apis::BatchV1::Message
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/batch_v1/classes.rb,
lib/google/apis/batch_v1/representations.rb,
lib/google/apis/batch_v1/representations.rb
Overview
Message details. Describe the conditions under which messages will be sent. If no attribute is defined, no message will be sent by default. One message should specify either the job or the task level attributes, but not both. For example, job level: JOB_STATE_CHANGED and/or a specified new_job_state; task level: TASK_STATE_CHANGED and/or a specified new_task_state.
Instance Attribute Summary collapse
-
#new_job_state ⇒ String
The new job state.
-
#new_task_state ⇒ String
The new task state.
-
#type ⇒ String
The message type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Message
constructor
A new instance of Message.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Message
Returns a new instance of Message.
1801 1802 1803 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_job_state ⇒ String
The new job state.
Corresponds to the JSON property newJobState
1789 1790 1791 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1789 def new_job_state @new_job_state end |
#new_task_state ⇒ String
The new task state.
Corresponds to the JSON property newTaskState
1794 1795 1796 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1794 def new_task_state @new_task_state end |
#type ⇒ String
The message type.
Corresponds to the JSON property type
1799 1800 1801 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1799 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1806 1807 1808 1809 1810 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1806 def update!(**args) @new_job_state = args[:new_job_state] if args.key?(:new_job_state) @new_task_state = args[:new_task_state] if args.key?(:new_task_state) @type = args[:type] if args.key?(:type) end |