Class: Google::Apis::BatchV1::NetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::BatchV1::NetworkInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/batch_v1/classes.rb,
lib/google/apis/batch_v1/representations.rb,
lib/google/apis/batch_v1/representations.rb
Overview
A network interface.
Instance Attribute Summary collapse
-
#network ⇒ String
The URL of an existing network resource.
-
#nic_type ⇒ String
Optional.
-
#no_external_ip_address ⇒ Boolean
(also: #no_external_ip_address?)
Default is false (with an external IP address).
-
#subnetwork ⇒ String
The URL of an existing subnetwork resource in the network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkInterface
constructor
A new instance of NetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkInterface
Returns a new instance of NetworkInterface.
1882 1883 1884 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network ⇒ String
The URL of an existing network resource. You can specify the network as a full
or partial URL. For example, the following are all valid URLs: * https://www.
googleapis.com/compute/v1/projects/project/global/networks/network *
projects/project/global/networks/network * global/networks/network
Corresponds to the JSON property network
1856 1857 1858 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1856 def network @network end |
#nic_type ⇒ String
Optional. The NIC type of the network interface.
Corresponds to the JSON property nicType
1861 1862 1863 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1861 def nic_type @nic_type end |
#no_external_ip_address ⇒ Boolean Also known as: no_external_ip_address?
Default is false (with an external IP address). Required if no external public
IP address is attached to the VM. If no external public IP address, additional
configuration is required to allow the VM to access Google Services. See https:
//cloud.google.com/vpc/docs/configure-private-google-access and https://cloud.
google.com/nat/docs/gce-example#create-nat for more information.
Corresponds to the JSON property noExternalIpAddress
1870 1871 1872 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1870 def no_external_ip_address @no_external_ip_address end |
#subnetwork ⇒ String
The URL of an existing subnetwork resource in the network. You can specify the
subnetwork as a full or partial URL. For example, the following are all valid
URLs: * https://www.googleapis.com/compute/v1/projects/`project`/regions/`
region/subnetworks/subnetwork* projects/project/regions/region/
subnetworks/subnetwork* regions/region/subnetworks/subnetwork
Corresponds to the JSON propertysubnetwork`
1880 1881 1882 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1880 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1887 1888 1889 1890 1891 1892 |
# File 'lib/google/apis/batch_v1/classes.rb', line 1887 def update!(**args) @network = args[:network] if args.key?(:network) @nic_type = args[:nic_type] if args.key?(:nic_type) @no_external_ip_address = args[:no_external_ip_address] if args.key?(:no_external_ip_address) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |